@@ -22,7 +22,9 @@ from .exec import (
     do_select_one,
     do_query,
     do_query_one,
-    get_connection
+    get_connection,
+    close,
 )
 from .support import DBError
 from .sql_exec import sql
+from .table_exec import table
