@@ -7,6 +7,7 @@ from .support import DBCtx, ConnectionCtx, Dict, MultiColumnsError, TransactionC
 from .constant import MYSQL_CONNECTOR_DRIVER, SQLITE, PARAM_DRIVER, PARAM_SHOW_SQL, PARAM_TRANS_PLACEHOLDER, PARAM_DEBUG, PARAM_POOL_SIZE
 
 _DB_CTX = None
+_POOLED = False
 
 
 def init_db(*args, **kwargs):
@@ -52,6 +53,8 @@ def init_db(*args, **kwargs):
     connect = lambda: creator.connect(*args, **kwargs)
     if pool_size >= 1 and not prepared:
         from .pooling import pooled_connect
+        global _POOLED
+        _POOLED = True
         connect = pooled_connect(connect, pool_size, **pool_kwargs)
 
     with DB_LOCK:
@@ -71,6 +74,7 @@ def init_db(*args, **kwargs):
 def connection():
     """
     Return ConnectionCtx object that can be used by 'with' statement:
+
     with connection():
         pass
     """
@@ -81,6 +85,7 @@ def connection():
 def with_connection(func):
     """
     Decorator for reuse connection.
+
     @with_connection
     def foo(*args, **kw):
         f1()
@@ -98,6 +103,7 @@ def with_connection(func):
 def transaction():
     """
     Create a transaction object so can use with statement:
+
     with transaction():
         pass
     with transaction():
@@ -111,6 +117,7 @@ def transaction():
 def with_transaction(func):
     """
     A decorator that makes function around transaction.
+
     @with_transaction
     def update_profile(id, name, rollback):
          u = dict(id=id, name=name, email='%s@test.org' % name, passwd=name, last_modified=time.time())
@@ -128,6 +135,7 @@ def with_transaction(func):
 def execute(sql: str, *args, **kwargs):
     """
     Execute sql return effect rowcount
+
     sql: INSERT INTO person(name, age) VALUES(?, ?)  -->  args: ('张三', 20)
          INSERT INTO person(name, age) VALUES(:name,:age)  -->  kwargs: {'name': '张三', 'age': 20}
     """
@@ -138,8 +146,9 @@ def execute(sql: str, *args, **kwargs):
 def insert(table: str, **kwargs):
     """
     Insert data into table, return effect rowcount.
+
     :param table: table name
-    :param kwargs: name='张三', age=20}
+    :param kwargs: {name='张三', age=20}
     return: Effect rowcount
     """
     insert_log('insert', table, **kwargs)
@@ -150,9 +159,10 @@ def insert(table: str, **kwargs):
 def save(select_key: str, table: str, **kwargs):
     """
     Insert data into table, return primary key.
+
     :param select_key: sql for select primary key
     :param table: table
-    :param kwargs:
+    :param kwargs: {name='张三', age=20}
     :return: Primary key
     """
     save_log('save', select_key, table, **kwargs)
@@ -163,9 +173,11 @@ def save(select_key: str, table: str, **kwargs):
 def save_sql(select_key: str, sql: str, *args, **kwargs):
     """
     Insert data into table, return primary key.
+
+    sql: INSERT INTO person(name, age) VALUES(?, ?)  -->  args: ('张三', 20)
+         INSERT INTO person(name, age) VALUES(:name,:age)  -->  kwargs: {'name': '张三', 'age': 20}
+
     :param select_key: sql for select primary key
-    :param sql: SQL
-    :param args:
     :return: Primary key
     """
     logger.debug("Exec func 'sqlexec.%s', 'select_key': %s \n\t sql: %s \n\t args: %s \n\t kwargs: %s" % ('save_sql', select_key, sql, args, kwargs))
@@ -176,9 +188,10 @@ def save_sql(select_key: str, sql: str, *args, **kwargs):
 def get(sql: str, *args, **kwargs):
     """
     Execute select SQL and expected one int and only one int result, SQL contain 'limit'.
+
     MultiColumnsError: Expect only one column.
     sql: SELECT count(1) FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
-         SELECT count(1) FROM person WHERE name=:name and age=:age limit 1  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+         SELECT count(1) FROM person WHERE name=:name and age=:age limit 1  --> kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.get', sql, *args, **kwargs)
     return do_get(sql, *args)
@@ -187,8 +200,9 @@ def get(sql: str, *args, **kwargs):
 def select(sql: str, *args, **kwargs):
     """
     execute select SQL and return unique result or list results(tuple).
+
     sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
-         SELECT * FROM person WHERE name=:name and age=:age  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+         SELECT * FROM person WHERE name=:name and age=:age --> kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.select', sql, *args, **kwargs)
     return do_select(sql, *args)
@@ -197,8 +211,9 @@ def select(sql: str, *args, **kwargs):
 def select_one(sql: str, *args, **kwargs):
     """
     Execute select SQL and return unique result(tuple), SQL contain 'limit'.
+
     sql: SELECT * FROM person WHERE name=? and age=? limit 1 -->  args: ('张三', 20)
-         SELECT * FROM person WHERE name=:name and age=:age limit 1  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+         SELECT * FROM person WHERE name=:name and age=:age limit 1 --> kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.select_one', sql, *args, **kwargs)
     return do_select_one(sql, *args)
@@ -208,7 +223,7 @@ def query(sql: str, *args, **kwargs):
     """
     Execute select SQL and return list results(dict).
     sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
-         SELECT * FROM person WHERE name=:name and age=:age  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+         SELECT * FROM person WHERE name=:name and age=:age --> kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.query', sql, *args, **kwargs)
     return do_query(sql, *args)
@@ -217,8 +232,9 @@ def query(sql: str, *args, **kwargs):
 def query_one(sql: str, *args, **kwargs):
     """
     execute select SQL and return unique result(dict), SQL contain 'limit'.
+
     sql: SELECT * FROM person WHERE name=? and age=? limit 1 -->  args: ('张三', 20)
-         SELECT * FROM person WHERE name=:name and age=:age limit 1  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+         SELECT * FROM person WHERE name=:name and age=:age limit 1 --> kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.query_one', sql, *args, **kwargs)
     return do_query_one(sql, *args)
@@ -227,6 +243,7 @@ def query_one(sql: str, *args, **kwargs):
 def do_execute(sql: str, *args):
     """
     Execute sql return effect rowcount
+
     sql: insert into person(name, age) values(?, ?)  -->  args: ('张三', 20)
     """
     return _execute(None, sql, *args)
@@ -235,6 +252,7 @@ def do_execute(sql: str, *args):
 def do_save_sql(select_key: str, sql: str, *args):
     """
     Insert data into table, return primary key.
+
     :param select_key: sql for select primary key
     :param sql: SQL
     :param args:
@@ -247,6 +265,7 @@ def do_get(sql: str, *args):
     """
     Execute select SQL and expected one int and only one int result, SQL contain 'limit'.
     MultiColumnsError: Expect only one column.
+
     sql: SELECT count(1) FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
     """
     do_sql_log('sqlexec.do_get', sql, *args)
@@ -346,6 +365,13 @@ def get_connection():
     return _DB_CTX.connection
 
 
+def close():
+    global _POOLED
+    if _POOLED:
+        from .pooling import close_pool
+        close_pool()
+
+
 @with_connection
 def _execute(select_key: str, sql: str, *args):
     global _DB_CTX
