@@ -1,3 +1,4 @@
+import threading
 from logging import basicConfig, INFO, getLogger
 
 logger = getLogger(__name__)
@@ -16,10 +17,10 @@ def sql_log(function: str, sql: str, *args, **kwargs):
     logger.debug("Exec func '%s' \n\tsql: %s \n\targs: %s \n\tkwargs: %s" % (function, sql.strip(), args, kwargs))
 
 
-def get_log(function: str, sql: str, *args):
-    logger.debug("Exec func 'sqlexec.%s' \n\t sql: %s \n\t args: %s" % (function, sql, args))
+def do_sql_log(function: str, sql: str, *args):
+    logger.debug("Exec func '%s' \n\t sql: %s \n\t args: %s" % (function, sql, args))
 
 
 def db_ctx_log(action, connection):
-    logger.debug('%s connection <%s>...' % (action, hex(id(connection))))
+    logger.debug("%s connection <%s>..." % (action, hex(id(connection))))
 
