@@ -20,3 +20,10 @@ def pooled_connect(creator, pool_size, **kwargs):
                 _POOL = PooledDB(creator, **kwargs)
     return _POOL.connection
 
+
+def close_pool():
+    global _POOL
+    if _POOL:
+        _POOL.close()
+        _POOL = None
+
