@@ -3,7 +3,7 @@ from .engine import Engine
 from typing import Sequence
 from .support import DBError
 from functools import lru_cache
-from .constant import CACHE_SIZE, NAMED_REGEX
+from .constant import CACHE_SIZE, NAMED_REGEX, LIMIT_1
 
 def insert_sql_args(table: str, **kwargs):
     cols, args = zip(*kwargs.items())
@@ -45,6 +45,22 @@ def get_named_sql_args(sql: str, **kwargs):
     return get_named_sql(sql), args
 
 
+def limit_one_sql_args(sql: str, *args):
+    if require_limit(sql):
+        return '{} LIMIT ?'.format(sql), [*args, LIMIT_1]
+    return sql, args
+
+
+def require_limit(sql: str):
+    lower_sql = sql.lower()
+    if 'limit' not in lower_sql:
+        return True
+    idx = lower_sql.rindex('limit')
+    if idx > 0 and ')' in lower_sql[idx:]:
+        return True
+    return False
+
+
 def is_mapping(sql: str):
     return ':' in sql
 
